@@ -20,6 +20,7 @@ use Doctrine\ORM\Mapping\Entity;
 use Doctrine\ORM\Mapping\GeneratedValue;
 use Doctrine\ORM\Mapping\Id;
 use Doctrine\ORM\Mapping\ManyToOne;
+use Doctrine\ORM\Mapping\MappingException;
 use Doctrine\ORM\Mapping\Version;
 use Doctrine\ORM\OptimisticLockException;
 use Doctrine\ORM\ORMInvalidArgumentException;
@@ -40,6 +41,7 @@ use PHPUnit\Framework\MockObject\MockObject;
 use stdClass;
 
 use function enum_exists;
+use function is_object;
 use function random_int;
 use function uniqid;
 
@@ -278,7 +280,19 @@ class UnitOfWorkTest extends OrmTestCase
         $user->username = 'John';
         $user->avatar   = $invalidValue;
 
-        $this->expectException(ORMInvalidArgumentException::class);
+        if (
+            is_object($invalidValue) &&
+            ! $invalidValue instanceof ArrayCollection &&
+            $this->_emMock->getConfiguration()->isNativeLazyObjectsEnabled()
+        ) {
+            // in the case of stdClass, the changeset is rejected because
+            // stdClass is not a valid entity
+            // when using native lazy objects, this happens because UnitOfWork::isUninitializedObject()
+            // needs to load the class metadata to do its job
+            $this->expectException(MappingException::class);
+        } else {
+            $this->expectException(ORMInvalidArgumentException::class);
+        }
 
         $this->_unitOfWork->computeChangeSet($metadata, $user);
     }
